﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using System.ComponentModel;
using Infragistics.Windows;
using System.Windows.Media.Animation;

namespace DataChartStartupAnimation
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            xamData.DataContext = Data.GetData(10, 10, 50);
        }
        Grid toAnimate;
        private void xamData_Loaded(object sender, RoutedEventArgs e)
        {
            ContentPresenter cp = Utilities.GetDescendantFromName(sender as DependencyObject, "ContentPresenter") as ContentPresenter;
            Border b = Utilities.GetDescendantFromType(cp, typeof(Border), false) as Border;
            toAnimate = (b.Child as Grid).Children[2] as Grid;
            RectangleGeometry rect  = 
                new RectangleGeometry(new Rect(0, 0,xamData.ActualWidth,xamData.ActualHeight ),0,0);
            
            toAnimate.Clip = rect;


            Storyboard initialAnim = new Storyboard();

            RectAnimation animation = new RectAnimation();
            Storyboard.SetTargetProperty(initialAnim, new PropertyPath("Clip.(RectangleGeometry.Rect)"));
            Storyboard.SetTarget(initialAnim, toAnimate);

            animation.Duration = new Duration(new TimeSpan(0, 0, 3));
            animation.From = new Rect(0, 0, 0, toAnimate.ActualHeight);
            animation.To = new Rect(0, 0, toAnimate.ActualWidth + 100, toAnimate.ActualHeight + 200);

            animation.Completed += new EventHandler(initialAnim_Completed);
            initialAnim.Children.Add(animation);
            initialAnim.Begin();                        
        }

        void initialAnim_Completed(object sender, EventArgs e)
        {
            toAnimate.Clip = null;   
        }
    }

    public class Data : INotifyPropertyChanged
    {
        private int open;
        private int close;
        private int high;
        private int low;
        private int value;
        private string label;

        public string Label
        {
            get { return label; }
            set
            {
                label = value;
                PropChanged("Label");
            }
        }

        public int Open
        {
            get { return open; }
            set
            {
                open = value;
                PropChanged("Open");
            }
        }

        public int Close
        {
            get { return close; }
            set
            {
                close = value;
                PropChanged("Close");
            }
        }

        public int High
        {
            get { return high; }
            set
            {
                high = value;
                PropChanged("High");
            }
        }

        public int Low
        {
            get { return low; }
            set
            {
                low = value;
                PropChanged("Low");
            }
        }

        public int Value
        {
            get { return value; }
            set
            {
                this.value = value;
                PropChanged("Value");
            }
        }

        public static ObservableCollection<Data> GetData(int points, int rangeStart, int rangeEnd)
        {
            ObservableCollection<Data> data = new ObservableCollection<Data>();
            Random r = new Random();
            for (int i = 0; i < points; i++)
            {
                data.Add(new Data
                {
                    Label = "Item " + i,
                    Open = r.Next(rangeStart, rangeEnd),
                    Close = r.Next(rangeStart, rangeEnd),
                    High = r.Next(rangeStart, rangeEnd),
                    Low = r.Next(rangeStart, rangeEnd),
                    Value = r.Next(rangeStart, rangeEnd),
                });
            }

            return data;
        }

        public event PropertyChangedEventHandler PropertyChanged;

        public void PropChanged(string name)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(name));
        }
    }
}
